@@ -3,12 +3,15 @@ import logging
 
 from .atc import parse_atc
 from .bluemaestro import parse_bluemaestro
+from .bparasite import parse_bparasite
 from .brifit import parse_brifit
 from .govee import parse_govee
+from .inkbird import parse_inkbird
 from .inode import parse_inode
 from .kegtron import parse_kegtron
 from .miscale import parse_miscale
 from .moat import parse_moat
+from .oral_b import parse_oral_b
 from .qingping import parse_qingping
 from .ruuvitag import parse_ruuvitag
 from .sensorpush import parse_sensorpush
@@ -70,7 +73,6 @@ class BleParser:
         # MAC address
         mac = (data[8 if is_ext_packet else 7:14 if is_ext_packet else 13])[::-1]
         sensor_data = None
-
         while adpayload_size > 1:
             adstuct_size = data[adpayload_start] + 1
             if adstuct_size > 1 and adstuct_size <= adpayload_size:
@@ -84,8 +86,11 @@ class BleParser:
                     if uuid16 == 0xFFF9 or uuid16 == 0xFDCD:  # UUID16 = Cleargrass or Qingping
                         sensor_data = parse_qingping(self, adstruct, mac, rssi)
                         break
-                    elif uuid16 == 0x181A:  # UUID16 = ATC
-                        sensor_data = parse_atc(self, adstruct, mac, rssi)
+                    elif uuid16 == 0x181A:  # UUID16 = ATC or b-parasite
+                        if len(adstruct) == 22 or len(adstruct) == 20:
+                            sensor_data = parse_bparasite(self, adstruct, mac, rssi)
+                        else:
+                            sensor_data = parse_atc(self, adstruct, mac, rssi)
                         break
                     elif uuid16 == 0xFE95:  # UUID16 = Xiaomi
                         sensor_data = parse_xiaomi(self, adstruct, mac, rssi)
@@ -138,6 +143,9 @@ class BleParser:
                     elif adstruct[0] == 0x14 and (comp_id == 0xaa55):  # Brifit
                         sensor_data = parse_brifit(self, adstruct, mac, rssi)
                         break
+                    if adstruct[0] == 0x0F and comp_id == 0x0000:  # Inkbird
+                        sensor_data = parse_inkbird(self, adstruct, mac, rssi)
+                        break
                     elif adstruct[0] == 0x0E and adstruct[3] == 0x82:  # iNode
                         sensor_data = parse_inode(self, adstruct, mac, rssi)
                         break
@@ -153,6 +161,9 @@ class BleParser:
                     elif adstruct[0] == 0x10 and adstruct[2] == 0xC0:  # Xiaogui Scale
                         sensor_data = parse_xiaogui(self, adstruct, mac, rssi)
                         break
+                    elif adstruct[0] == 0x0E and comp_id == 0x00DC:  # Oral-b
+                        sensor_data = parse_oral_b(self, adstruct, mac, rssi)
+                        break
                     else:
                         if self.report_unknown == "Other":
                             _LOGGER.info("Unknown advertisement received: %s", data.hex())
