@@ -15,6 +15,7 @@ XIAOMI_TYPE_DICT = {
     0x045B: "LYWSD02",
     0x055B: "LYWSD03MMC",
     0x1203: "XMWSDJ04MMC",
+    0x04E1: "XMMF01JQD",
     0x0098: "HHCCJCY01",
     0x03BC: "GCLS002",
     0x015D: "HHCCPOT002",
@@ -225,7 +226,7 @@ def obj000f(xobj, device_type):
             return {"motion": 1, "motion timer": 1, "light": int(value >= 100)}
         elif device_type == "CGPR1":
             # CGPR1:     moving, value is illumination in lux
-            return {"motion": 1, "motion timer": 1, "illuminance": value}
+            return {"motion": 1, "motion timer": 1, "illuminance": value, "light": int(value >= 100)}
         else:
             return {}
     else:
@@ -312,14 +313,17 @@ def obj1001(xobj, device_type):
         # press type and dimmer
         button_press_type = "no press"
         btn_switch_press_type = "no press"
+        cube_direction = None
         dimmer = None
 
         if press == 0:
             button_press_type = "single press"
             btn_switch_press_type = "single press"
+            cube_direction = "right"
         elif press == 1:
             button_press_type = "double press"
             btn_switch_press_type = "long press"
+            cube_direction = "left"
         elif press == 2:
             button_press_type = "long press"
             btn_switch_press_type = "double press"
@@ -351,8 +355,10 @@ def obj1001(xobj, device_type):
 
         # return device specific output
         result = {}
-        if device_type in ["RTCGQ02LM", "YLAI003", "JTYJGD03MI"]:
+        if device_type in ["RTCGQ02LM", "YLAI003", "JTYJGD03MI", "SJWS01LM"]:
             result["button"] = button_press_type
+        elif device_type == "XMMF01JQD":
+            result["button"] = cube_direction
         elif device_type == "YLYK01YL":
             result["remote"] = remote_command
             result["button"] = button_press_type
@@ -877,4 +883,5 @@ def decrypt_mibeacon_legacy(self, data, i, xiaomi_mac):
 
 
 def to_mac(addr: int):
+    """Return formatted MAC address"""
     return ':'.join('{:02x}'.format(x) for x in addr).upper()
